# Copyright (c) 2000-2005, JPackage Project
# https://github.com/fedora-java/javapackages/blob/master/LICENSE

Summary:	JDBC driver for PostgreSQL
Name:		postgresql-jdbc
Version:	42.5.6
Release:	3%{?dist}
License:	BSD-2-Clause
URL:		http://jdbc.postgresql.org/
Source0:	https://repo1.maven.org/maven2/org/postgresql/postgresql/%{version}/postgresql-%{version}-jdbc-src.tar.gz
Provides:	pgjdbc = %version-%release

BuildArch:	noarch
ExclusiveArch:  %{java_arches} noarch

BuildRequires:	java-devel
BuildRequires:	maven-local maven-enforcer-plugin maven-plugin-bundle
BuildRequires:	classloader-leak-test-framework
BuildRequires:	mvn(com.ongres.scram:client)
BuildRequires:	mvn(org.apache.maven.surefire:surefire-junit-platform)
BuildRequires:	mvn(org.junit.jupiter:junit-jupiter-api)
BuildRequires:	mvn(org.junit.jupiter:junit-jupiter-engine)
BuildRequires:	mvn(org.junit.jupiter:junit-jupiter-params)
BuildRequires:	mvn(org.junit.vintage:junit-vintage-engine)
# For selftest
BuildRequires:	postgresql-contrib postgresql-test-rpm-macros


%description
The PostgreSQL JDBC Driver allows Java programs to connect to a PostgreSQL database
using standard, database independent Java code. pgJDBC is an open source JDBC driver
written in Pure Java (Type 4), and communicates in the PostgreSQL native network protocol.


%package javadoc
Summary:	API docs for %{name}

%description javadoc
This package contains the API Documentation for %{name}.


%prep
%setup -c -q
mv postgresql-%{version}-jdbc-src/* .
find -type f \( -name "*.jar" -or -name "*.class" \) | xargs rm -f

%pom_xpath_remove "pom:plugin[pom:artifactId = 'maven-shade-plugin']"
%mvn_file org.postgresql:postgresql %{name}/postgresql %{name} postgresql
%mvn_alias org.postgresql:postgresql postgresql:postgresql
%pom_remove_dep uk.org.webcompere:system-stubs-jupiter
rm src/test/java/org/postgresql/test/jdbc2/DriverTest.java \
   src/test/java/org/postgresql/util/OSUtilTest.java \
   src/test/java/org/postgresql/jdbcurlresolver/PgServiceConfParserTest.java \
   src/test/java/org/postgresql/jdbcurlresolver/PgPassParserTest.java \
   src/test/java/org/postgresql/util/StubEnvironmentAndProperties.java


%build
%postgresql_tests_init

PGTESTS_LOCALE=C.UTF-8

cat <<EOF > build.local.properties
server=localhost
port=$PGTESTS_PORT
database=test
username=test
password=test
privilegedUser=$PGTESTS_ADMIN
privilegedPassword=$PGTESTS_ADMINPASS
preparethreshold=5
loglevel=0
protocolVersion=0
EOF

%postgresql_tests_start

%mvn_build $opts --xmvn-javadoc


%install
%mvn_install


%files -f .mfiles
%license LICENSE
%doc README.md


%files javadoc -f .mfiles-javadoc
%license LICENSE


%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 42.5.6-3
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 42.5.6-2
- Rebuilt for loongarch release

* Tue Jun 04 2024 Upgrade Robot <upbot@opencloudos.tech> - 42.5.6-1
- Upgrade to version 42.5.6
- fix CVE-2024-1597

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 42.5.2-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 42.5.2-2
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 25 2023 rockerzhu <rockerzhu@tencent.com> - 42.5.2-1
- Initial build.
